

RegistryService
=================================

.. currentmodule:: pyvo.registry.vao

.. autoclass:: RegistryService
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~RegistryService.STSCI_REGISTRY_BASEURL

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~RegistryService.create_query
      ~RegistryService.resolve
      ~RegistryService.search

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: STSCI_REGISTRY_BASEURL

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: create_query
   .. automethod:: resolve
   .. automethod:: search

   
   